//*******************************************************************************************
//	Example code for EZ-Controller available from http://www.sourceboost.com/Products/Products.html
//
//	Sample of USART transmission and Interrupts using the EZ-Controller 
//	
//	This sample receives a character and send it back, sending
//	string "You pressed" before the character.
//
//			
//	**Note:	The Two top Configuration Jumpers must be in position Tx (1-2) and Rx (5-6)
//		otherwise the microcontroller is set up for Rc6 and Rc7 pin out use.
//
//
//	Use hyperterminal at 19200,8,n,1
//
// Author: Richard Martin
//
// Thanks to Marc-Andr Boulianne alias KaLaMyR
// KaLaMyR@hotmail.com
//
//********************************************************************************************
//
// This code will work with EZ-Controller or EZ-Controller Turbo, but there are a couple
// of this you need correctly set:
//
// 1) Ensure you have the correct linker command line option for your target
// Menu Settings->Options->Compile Options->Extra Linker Options:
// '-rb 0x200' for EZ-Controller.
// '-rb 0x800' for EZ-Controller Turbo.
//
// 2) Make sure you have the correct target device selected:
// PIC18F252  for EZ-Controller
// PIC18F2520 for EZ-Controller Turbo

#pragma CLOCK_FREQ 20000000

#include <system.h>


void putc(char txc)			// Put char function to transmit one char
{
	txreg = txc;					// Put function parameter txc into the txreg	
	set_bit( txsta, TXEN );			// Enable transmission bit
	while(( txsta&0x02 ) == 0 );	// Wait until character transmission finished
}

char getc(void)				// Getc function loop until a character is pressed
{
	while( ( pir1&0x20 ) != 0x20 );	// Loop until Rxflag = 1
	return rcreg;			// Return rcreg
}

void puts(char *source)		//	put string function, return the refered string
{
	while (*source != 0 ) // wait until tx register is empty
	{ 
		putc(*source++);	// Send the string refered by pointer
	}
}	

void interrupt( void )		// Called function on interrupts
{	
	if( ( pir1&0x20 ) == 0x20 ) // If Rxflag = 1 then ----->
	{
		puts("You pressed "); // Send the string "You pressed "
		putc( getc() ); // Call getc function then put the character pressed
		putc(0x0d);		// Carriage Return
		putc(0x0a);		// Line Feed
	}
	

}
void main()
{
		
	trisc = 128;		//Set RC6/TX as an output and RC7/RX as an input
	clear_bit( pir1,RCIF ); //Clear UART interrupt flag
	txsta = 0x06;			//Enable uart module and set 8,n,1
	rcsta = 0x90;			//Enable continuous receive and set 8,n,1
	pie1 = 0x20;			//Enable UART receive interrupt
	intcon = 0xD0;			//Enable global, peripheral and INT0 interrupt
	spbrg = 64;				//Set SPBRG to 19 200 BPS
	
	
	while (1);
		
}

